@@ -15,6 +15,8 @@
 #define PHIDGETS_USB_PRODUCTID_INTERFACEKIT_0_5_7 0x0051
 #define PHIDGETS_USB_PRODUCTID_INTERFACEKIT_0_8_8 0x0053
 
+#define PHIDGETS_USB_PRODUCTID_LED64 0x004a
+
 /* InterfaceKit 0/5/7 = AnalogIn / DigitalIn / DigitalOut */
 #define PHIDGETS_INTERFACEKIT_MAX_ANALOG_INPUTS 8
 #define PHIDGETS_INTERFACEKIT_MAX_DIGITAL_INPUTS 16
@@ -28,6 +30,7 @@
 #define PHIDGETS_HID_PATH_INTERFACEKIT_DIGITAL_OUTPUT_SET 0xffa10008
 #define PHIDGETS_HID_PATH_INTERFACEKIT_DIGITAL_OUTPUT_GET 0xffa10000
 #define PHIDGETS_HID_PATH_RFID_SET 0xffa1000b
+#define PHIDGETS_HID_PATH_LED64_SET 0xffa10008
 
 #define PHIDGETS_RFID_SET_PACKETLEN 4
 #define PHIDGETS_RFID_GET_PACKETLEN 7
@@ -38,6 +41,9 @@
 #define PHIDGETS_RFID_ONBOARD_LED 0x4
 #define PHIDGETS_RFID_ENABLE 0x8
 
+#define PHIDGETS_LED64_NUMLEDS 64
+#define PHIDGETS_LED64_SET_PACKETLEN 8
+
 #define USB_CONTROL_DATA_SOMETHINGELSE 0x80
 #define USB_CONTROL_DATA_WRITE 0x40
 #define USB_CONTROL_DATA_READ 0x00
